@@ -101,8 +101,8 @@ def getUserPassword(flag="dialog", pwDialog=False):
             if not pwDialog:
                 pwDialog = [_("New password"),
                             _("Retype the new password")]
-            pwdA = getpass.getpass(pwDialog[0]+":")
-            pwdB = getpass.getpass(pwDialog[1]+":")
+            pwdA = getpass.getpass(pwDialog[0]+_(":"))
+            pwdB = getpass.getpass(pwDialog[1]+_(":"))
         elif flag == "stdin":
             pwdA = sys.stdin.readline().rstrip()
             pwdB = sys.stdin.readline().rstrip()
@@ -175,12 +175,23 @@ def getInstalledVideo(prefix="/"):
 def getDistfilesVideo(prefix="/"):
     """Get video drivers from distfiles"""
     distFiles = path.join(prefix,"usr/portage/distfiles")
+    driver_map = {'ati':'fglrx',
+                  'amd':'fglrx',
+                  'nvidia-linux':'nvidia',
+                  'fglrx':'fglrx'}
+
+    def driver_by_fn(fn):
+        fn = fn.lower()
+        for part in driver_map:
+            if part in fn:
+                return driver_map[part]
+        else:
+            return None
+
     return list(set(
-           map(lambda x:'fglrx' if "amd" in x or "ati" in x else "nvidia",
-           filter(lambda x:"ati" in x or "amd" in x or
-                           x.startswith('nvidia-linux'),
-           map(lambda x:x.lower(),
-           listDirectory(distFiles))))))
+           filter(None,
+           map(driver_by_fn,
+           listDirectory(distFiles)))))
 
 def getAvailableVideo(prefix="/"):
     """Get available video drivers (installed and maybe installed)"""
@@ -276,7 +287,7 @@ def getValueFromConfig(config,name):
 def getVideoFromXorgLog(prefix="/",available_drivers=[]):
     """Get video driver from Xorg log"""
     # Try analize Xorg.{DISPLAY}.log
-    display = os.environ.get('DISPLAY','0')
+    display = os.environ.get('DISPLAY',':0')
     if display and available_drivers:
         reDriver = re.compile('|'.join(map(lambda x: "%s_drv.so"%x,
                                            available_drivers)))
